@@ -9,7 +9,7 @@ cleanBowlerData <- function(file) {
     
     BPO <- Overs <- NULL
     # Read the <bowler>.csv file
-    df <- read.csv(file,stringsAsFactor=FALSE,na.strings=c(NA,"-"),quote="")
+    df <- read.csv(file,stringsAsFactor=FALSE,na.strings=c(NA,"-"))
     
     # Remove rows with did not bowl
     a <- df$Overs != "DNB"
@@ -22,6 +22,9 @@ cleanBowlerData <- function(file) {
     # Get all complete cases
     c <- complete.cases(bowler)
     bowlerComplete <- bowler[c,]
+    
+    # Fix the Opposition column, remove "^ v"
+    bowlerComplete$Opposition =gsub("^v ","",bowlerComplete$Opposition)
 
     # Normalize overs which had 8 balls per over to the number of overs if there 8 balls per over
     if(names(bowlerComplete)[3] == "BPO") {
